Opt

Struct Opt 

pub struct Opt {
Show 46 fields pub help: Option<bool>, pub version: Option<bool>, pub verbose: u8, pub init: Option<Option<String>>, pub config: PathBuf, pub config_url: Option<Url>, pub workdir: Option<PathBuf>, pub repository: Option<Vec<PathBuf>>, pub include_path: Option<Vec<Pattern>>, pub exclude_path: Option<Vec<Pattern>>, pub tag_pattern: Option<Regex>, pub with_commit: Option<Vec<String>>, pub with_tag_message: Option<String>, pub skip_tags: Option<Regex>, pub ignore_tags: Option<Regex>, pub count_tags: Option<Regex>, pub skip_commit: Option<Vec<String>>, pub prepend: Option<PathBuf>, pub output: Option<PathBuf>, pub tag: Option<String>, pub bump: Option<BumpOption>, pub bumped_version: bool, pub body: Option<String>, pub latest: bool, pub current: bool, pub unreleased: bool, pub topo_order: bool, pub use_branch_tags: bool, pub no_exec: bool, pub context: bool, pub from_context: Option<PathBuf>, pub strip: Option<Strip>, pub sort: Sort, pub github_token: Option<SecretString>, pub github_repo: Option<RemoteValue>, pub gitlab_token: Option<SecretString>, pub gitlab_repo: Option<RemoteValue>, pub gitea_token: Option<SecretString>, pub gitea_repo: Option<RemoteValue>, pub bitbucket_token: Option<SecretString>, pub bitbucket_repo: Option<RemoteValue>, pub azure_devops_token: Option<SecretString>, pub azure_devops_repo: Option<RemoteValue>, pub range: Option<String>, pub use_native_tls: bool, pub offline: bool,
}
Command-line arguments to parse.

Fields

help: Option<bool>version: Option<bool>verbose: u8

Increases the logging verbosity.

init: Option<Option<String>>

Writes the default configuration file to cliff.toml

config: PathBuf

Sets the configuration file.

config_url: Option<Url>

Sets the URL for the configuration file.

workdir: Option<PathBuf>

Sets the working directory.

repository: Option<Vec<PathBuf>>

Sets the git repository.

include_path: Option<Vec<Pattern>>

Sets the path to include related commits.

exclude_path: Option<Vec<Pattern>>

Sets the path to exclude related commits.

tag_pattern: Option<Regex>

Sets the regex for matching git tags.

with_commit: Option<Vec<String>>

Sets custom commit messages to include in the changelog.

with_tag_message: Option<String>

Sets custom message for the latest release.

skip_tags: Option<Regex>

Sets the tags to skip in the changelog.

ignore_tags: Option<Regex>

Sets the tags to ignore in the changelog.

count_tags: Option<Regex>

Sets the tags to count in the changelog.

skip_commit: Option<Vec<String>>

Sets commits that will be skipped in the changelog.

prepend: Option<PathBuf>

Prepends entries to the given changelog file.

output: Option<PathBuf>

Writes output to the given file.

tag: Option<String>

Sets the tag for the latest version.

bump: Option<BumpOption>

Bumps the version for unreleased changes. Optionally with specified version.

bumped_version: bool

Prints bumped version for unreleased changes.

body: Option<String>

Sets the template for the changelog body.

latest: bool

Processes the commits starting from the latest tag.

current: bool

Processes the commits that belong to the current tag.

unreleased: bool

Processes the commits that do not belong to a tag.

topo_order: bool

Sorts the tags topologically.

use_branch_tags: bool

Include only the tags that belong to the current branch.

no_exec: bool

Disables the external command execution.

context: bool

Prints changelog context as JSON.

from_context: Option<PathBuf>

Generates changelog from a JSON context.

strip: Option<Strip>

Strips the given parts from the changelog.

sort: Sort

Sets sorting of the commits inside sections.

github_token: Option<SecretString>

Sets the GitHub API token.

github_repo: Option<RemoteValue>

Sets the GitHub repository.

gitlab_token: Option<SecretString>

Sets the GitLab API token.

gitlab_repo: Option<RemoteValue>

Sets the GitLab repository.

gitea_token: Option<SecretString>

Sets the Gitea API token.

gitea_repo: Option<RemoteValue>

Sets the Gitea repository.

bitbucket_token: Option<SecretString>

Sets the Bitbucket API token.

bitbucket_repo: Option<RemoteValue>

Sets the Bitbucket repository.

azure_devops_token: Option<SecretString>

Sets the Azure DevOps API token.

azure_devops_repo: Option<RemoteValue>

Sets the Azure DevOps repository.

range: Option<String>

Sets the commit range to process.

use_native_tls: bool

Load TLS certificates from the native certificate store.

offline: bool

Disable network access for remote repositories.