pub struct Opt {Show 20 fields
pub verbose: u8,
pub config: PathBuf,
pub workdir: Option<PathBuf>,
pub repository: Option<PathBuf>,
pub include_path: Option<Vec<Pattern>>,
pub exclude_path: Option<Vec<Pattern>>,
pub with_commit: Option<Vec<String>>,
pub prepend: Option<PathBuf>,
pub output: Option<PathBuf>,
pub tag: Option<String>,
pub body: Option<String>,
pub init: bool,
pub latest: bool,
pub current: bool,
pub unreleased: bool,
pub topo_order: bool,
pub context: bool,
pub strip: Option<Strip>,
pub sort: Sort,
pub range: Option<String>,
}Expand description
Command-line arguments to parse.
Fields
verbose: u8Increases the logging verbosity.
config: PathBufSets the configuration file.
workdir: Option<PathBuf>Sets the working directory.
repository: Option<PathBuf>Sets the git repository.
include_path: Option<Vec<Pattern>>Sets the path to include related commits.
exclude_path: Option<Vec<Pattern>>Sets the path to exclude related commits.
with_commit: Option<Vec<String>>Sets custom commit messages to include in the changelog.
prepend: Option<PathBuf>Prepends entries to the given changelog file.
output: Option<PathBuf>Writes output to the given file.
tag: Option<String>Sets the tag for the latest version.
body: Option<String>Sets the template for the changelog body.
init: boolWrites the default configuration file to cliff.toml
latest: boolProcesses the commits starting from the latest tag.
current: boolProcesses the commits that belong to the current tag.
unreleased: boolProcesses the commits that do not belong to a tag.
topo_order: boolSorts the tags topologically.
context: boolPrints changelog context as JSON.
strip: Option<Strip>Strips the given parts from the changelog.
sort: SortSets sorting of the commits inside sections.
range: Option<String>Sets the commit range to process.